==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/ker/ker-gamestruct.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdlib.h>

#include "config.h"
#include "ker.h"
#include "ker-internal.h"

/*
 * This is used to stamp game_structs as they are created.
 * Note that there's no race condition due to the fact that this
 * is global here, in fact even when 2 processes would share
 * this sequence id, it would not matter for they would then
 * try and identify the objects in their on per-process lists,
 * structures, Guile object, whatever they use.
 */
static int seq_id = 0;

LW6KER_GAME_STRUCT *
lw6ker_game_struct_new (LW6MAP_MAP * map)
{
  LW6KER_GAME_STRUCT *ret = NULL;

  ret = (LW6KER_GAME_STRUCT *) LW6SYS_CALLOC (sizeof (LW6KER_GAME_STRUCT));

  if (ret)
    {
      ret->id = ++seq_id;
      lw6opt_static_copy (&(ret->options), &(map->param.options));
      _lw6ker_map_struct_init (&(ret->map), map);
    }

  return ret;
}

void
lw6ker_game_struct_free (LW6KER_GAME_STRUCT * game_struct)
{
  _lw6ker_map_struct_clear (&(game_struct->map));
  LW6SYS_FREE (game_struct);
}

int
lw6ker_game_struct_memory_footprint (LW6KER_GAME_STRUCT * game_struct)
{
  int ret = 0;

  // todo

  return ret;
}

char *
lw6ker_game_struct_repr (LW6KER_GAME_STRUCT * game_struct)
{
  char *ret = NULL;

  if (game_struct)
    {
      ret =
	lw6sys_new_sprintf ("%d (%dx%d)", game_struct->id,
			    game_struct->map.shape.w,
			    game_struct->map.shape.h);
    }
  else
    {
      lw6sys_log (LW6SYS_LOG_WARNING, "game_struct",
		  _("can't generate string id for NULL game_struct"));
    }

  return ret;
}

void
_lw6ker_game_struct_update_checksum (LW6KER_GAME_STRUCT *
				     game_struct, LW6SYS_UINT32 * checksum)
{
  _lw6ker_map_struct_update_checksum (&(game_struct->map), checksum);
  lw6opt_static_update_checksum (&(game_struct->options), checksum);
}

LW6SYS_UINT32
lw6ker_game_struct_checksum (LW6KER_GAME_STRUCT * game_struct)
{
  LW6SYS_UINT32 ret = 0;

  _lw6ker_game_struct_update_checksum (game_struct, &ret);

  return ret;
}

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/ker/ker-gamestruct.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdlib.h>

#include "config.h"
#include "ker.h"
#include "ker-internal.h"

/*
 * This is used to stamp game_structs as they are created.
 * Note that there's no race condition due to the fact that this
 * is global here, in fact even when 2 processes would share
 * this sequence id, it would not matter for they would then
 * try and identify the objects in their on per-process lists,
 * structures, Guile object, whatever they use.
 */
static int seq_id = 0;

LW6KER_GAME_STRUCT *
lw6ker_game_struct_new (LW6MAP_MAP * map)
{
  LW6KER_GAME_STRUCT *ret = NULL;

  ret = (LW6KER_GAME_STRUCT *) LW6SYS_CALLOC (sizeof (LW6KER_GAME_STRUCT));

  if (ret)
    {
      ret->id = ++seq_id;
      lw6opt_static_copy (&(ret->options), &(map->param.options));
      _lw6ker_map_struct_init (&(ret->map), map);
    }

  return ret;
}

void
lw6ker_game_struct_free (LW6KER_GAME_STRUCT * game_struct)
{
  _lw6ker_map_struct_clear (&(game_struct->map));
  LW6SYS_FREE (game_struct);
}

int
lw6ker_game_struct_memory_footprint (LW6KER_GAME_STRUCT * game_struct)
{
  int ret = 0;

  // todo

  return ret;
}

char *
lw6ker_game_struct_repr (LW6KER_GAME_STRUCT * game_struct)
{
  char *ret = NULL;

  if (game_struct)
    {
      ret =
	lw6sys_new_sprintf ("%d (%dx%d)", game_struct->id,
			    game_struct->map.shape.w,
			    game_struct->map.shape.h);
    }
  else
    {
      lw6sys_log (LW6SYS_LOG_WARNING, "game_struct",
		  _("can't generate string id for NULL game_struct"));
    }

  return ret;
}

void
_lw6ker_game_struct_update_checksum (LW6KER_GAME_STRUCT *
				     game_struct, LW6SYS_UINT32 * checksum)
{
  _lw6ker_map_struct_update_checksum (&(game_struct->map), checksum);
  lw6opt_static_update_checksum (&(game_struct->options), checksum);
}

LW6SYS_UINT32
lw6ker_game_struct_checksum (LW6KER_GAME_STRUCT * game_struct)
{
  LW6SYS_UINT32 ret = 0;

  _lw6ker_game_struct_update_checksum (game_struct, &ret);

  return ret;
}
